@@ -63,6 +63,23 @@ def test_ChangesetGet(api, add_response):
     assert result == test_changeset
 
 
+def test_ChangesetGet_with_connection_error(api, add_response):
+    # Setup mock
+    add_response(
+        GET,
+        "/changeset/123",
+        body=requests.exceptions.ConnectionError("Connection aborted."),
+    ),
+
+    # Call
+    with pytest.raises(osmapi.ConnectionApiError) as execinfo:
+        api.ChangesetGet(123)
+    assert (
+        str(execinfo.value)
+        == "Request failed: 0 - Connection error: Connection aborted. - "
+    )
+
+
 def test_ChangesetGet_with_timeout(api, add_response):
     # Setup mock
     add_response(GET, "/changeset/123", body=requests.exceptions.Timeout())
@@ -87,10 +104,10 @@ def test_ChangesetUpdate(auth_api, add_response):
     result = auth_api.ChangesetUpdate({"test": "foobar"})
     changeset_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osm version="0.6" generator="osmapi/4.2.0">\n'
+        b'<osm version="0.6" generator="osmapi/4.3.0">\n'
         b'  <changeset visible="true">\n'
         b'    <tag k="test" v="foobar"/>\n'
-        b'    <tag k="created_by" v="osmapi/4.2.0"/>\n'
+        b'    <tag k="created_by" v="osmapi/4.3.0"/>\n'
         b"  </changeset>\n"
         b"</osm>\n"
     )
@@ -110,7 +127,7 @@ def test_ChangesetUpdate_with_created_by(auth_api, add_response):
     result = auth_api.ChangesetUpdate({"test": "foobar", "created_by": "MyTestOSMApp"})
     changeset_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osm version="0.6" generator="osmapi/4.2.0">\n'
+        b'<osm version="0.6" generator="osmapi/4.3.0">\n'
         b'  <changeset visible="true">\n'
         b'    <tag k="test" v="foobar"/>\n'
         b'    <tag k="created_by" v="MyTestOSMApp"/>\n'
@@ -134,10 +151,10 @@ def test_ChangesetCreate(auth_api, add_response):
 
     changeset_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osm version="0.6" generator="osmapi/4.2.0">\n'
+        b'<osm version="0.6" generator="osmapi/4.3.0">\n'
         b'  <changeset visible="true">\n'
         b'    <tag k="foobar" v="A new test changeset"/>\n'
-        b'    <tag k="created_by" v="osmapi/4.2.0"/>\n'
+        b'    <tag k="created_by" v="osmapi/4.3.0"/>\n'
         b"  </changeset>\n"
         b"</osm>\n"
     )
@@ -157,7 +174,7 @@ def test_ChangesetCreate_with_created_by(auth_api, add_response):
 
     changeset_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osm version="0.6" generator="osmapi/4.2.0">\n'
+        b'<osm version="0.6" generator="osmapi/4.3.0">\n'
         b'  <changeset visible="true">\n'
         b'    <tag k="foobar" v="A new test changeset"/>\n'
         b'    <tag k="created_by" v="CoolTestApp"/>\n'
@@ -237,7 +254,7 @@ def test_ChangesetUpload_create_node(auth_api, add_response):
 
     upload_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osmChange version="0.6" generator="osmapi/4.2.0">\n'
+        b'<osmChange version="0.6" generator="osmapi/4.3.0">\n'
         b"<create>\n"
         b'  <node lat="47.123" lon="8.555" visible="true" '
         b'changeset="4444">\n'
@@ -309,7 +326,7 @@ def test_ChangesetUpload_modify_way(auth_api, add_response):
 
     upload_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osmChange version="0.6" generator="osmapi/4.2.0">\n'
+        b'<osmChange version="0.6" generator="osmapi/4.3.0">\n'
         b"<modify>\n"
         b'  <way id="4294967296" version="2" visible="true" '
         b'changeset="4444">\n'
@@ -382,7 +399,7 @@ def test_ChangesetUpload_delete_relation(auth_api, add_response):
 
     upload_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osmChange version="0.6" generator="osmapi/4.2.0">\n'
+        b'<osmChange version="0.6" generator="osmapi/4.3.0">\n'
         b"<delete>\n"
         b'  <relation id="676" version="2" visible="true" '
         b'changeset="4444">\n'
